import { Close, CloseFullscreen, Minimize } from "@mui/icons-material";
import { Box, Button, ButtonGroup, Stack, useTheme } from "@mui/material";
import { WebviewWindow } from "@tauri-apps/api/window";
import { useEffect, useState } from "react";

export const WindowButtons = () => {
  const userTheme = useTheme();

  const [appWindow, setAppWindow] = useState<WebviewWindow>();

  // explanation:
  // this is needed due to the server-sided nature of next js,
  // this means that the window object might not be available on first load
  // we will use dynamic imports to load the window object only when needed
  // in hindsight, using next js for this project was a mistake
  // using create-react-app or vite would have been a better choice just to generate a static site
  const initializeAppWindow = async () => {
    const { appWindow } = await import("@tauri-apps/api/window");
    setAppWindow(appWindow);
  };

  const minimize = () => {
    appWindow?.minimize();
  };

  const maximize = () => {
    appWindow?.toggleMaximize();
  };

  const close = () => {
    appWindow?.close();
  };

  useEffect(() => {
    initializeAppWindow();
  });

  return (
    <Box>
      <Stack direction="row" spacing={1}>
        <ButtonGroup>
          <Button
            onClick={minimize}
            sx={{
              backgroundColor: userTheme.palette.grey[800],
            }}
          >
            <Minimize
              fontSize="inherit"
              sx={{
                backgroundColor: userTheme.palette.grey[800],
              }}
            />
          </Button>
          <Button
            onClick={maximize}
            sx={{
              backgroundColor: userTheme.palette.grey[800],
            }}
          >
            <CloseFullscreen fontSize="inherit" />
          </Button>
          <Button
            onClick={close}
            sx={{
              backgroundColor: userTheme.palette.grey[800],
            }}
          >
            <Close fontSize="inherit" />
          </Button>
        </ButtonGroup>
      </Stack>
    </Box>
  );
};
